@@ -6,13 +6,12 @@ package Test::Class;
 
 use Attribute::Handlers;
 use Carp;
-use Class::ISA;
-use Devel::Symdump;
+use MRO::Compat;
 use Storable qw(dclone);
 use Test::Builder;
 use Test::Class::MethodInfo;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 my $Check_block_has_run;
 {
@@ -83,7 +82,9 @@ sub _parse_attribute_args {
 
 sub _is_public_method {
     my ($class, $name) = @_;
-    foreach my $parent_class ( Class::ISA::super_path( $class ) ) {
+    my @parents = @{mro::get_linear_isa($class)};
+    shift @parents;
+    foreach my $parent_class ( @parents ) {
         return unless $parent_class->can( $name );
         return if _method_info( $class, $parent_class, $name );
     }
@@ -141,7 +142,7 @@ sub _get_methods {
     die "TEST_METHOD ($test_method_regexp) is not a valid regexp: $@" if $@;
 	
 	my %methods = ();
-	foreach my $class ( Class::ISA::self_and_super_path( $test_class ) ) {
+	foreach my $class ( @{mro::get_linear_isa( $test_class )} ) {
 		foreach my $info ( _methods_of_class( $self, $class ) ) {
 		    my $name = $info->name;
 			foreach my $type ( @types ) {
@@ -197,7 +198,7 @@ sub _total_num_tests {
 	my $class = _class_of( $self );
 	my $total_num_tests = 0;
 	foreach my $method (@methods) {
-		foreach my $class (Class::ISA::self_and_super_path($class)) {
+		foreach my $class (@{mro::get_linear_isa($class)}) {
 			my $info = _method_info($self, $class, $method);
 			next unless $info;
 			my $num_tests = $info->num_tests;
@@ -309,7 +310,7 @@ sub _isa_class {
 
 sub _test_classes {
 	my $class = shift;
-	return grep { _isa_class( $class, $_ ) } Devel::Symdump->rnew->packages;
+	return( @{mro::get_isarev($class)}, $class );
 };
 
 sub runtests {
@@ -451,12 +452,12 @@ Test::Class - Easily create test classes in an xUnit/JUnit style
       my $array = shift->{test_array};
       diag("array = (@$array) after test(s)");
   };
-  
+
 later in a nearby .t file
 
   #! /usr/bin/perl
   use Example::Test;
-  
+
   # run all the test methods in Example::Test
   Test::Class->runtests;
 
@@ -476,9 +477,9 @@ Outputs:
 
 Test::Class provides a simple way of creating classes and objects to test your code in an xUnit style. 
 
-Built using L<Test::Builder> it is designing to work with other Test::Builder based modules (L<Test::More>, L<Test::Differences>, L<Test::Exception>, etc.)  
+Built using L<Test::Builder>, it was designed to work with other Test::Builder based modules (L<Test::More>, L<Test::Differences>, L<Test::Exception>, etc.).
 
-I<Note:> This module will make more sense if you are already familiar with the "standard" mechanisms for testing perl code. Those unfamiliar  with L<Test::Harness>, L<Test::Simple>, L<Test::More> and friends should go take a look at them now. L<Test::Tutorial> is a good starting point.
+I<Note:> This module will make more sense, if you are already familiar with the "standard" mechanisms for testing perl code. Those unfamiliar with L<Test::Harness>, L<Test::Simple>, L<Test::More> and friends should go take a look at them now. L<Test::Tutorial> is a good starting point.
 
 
 =head1 INTRODUCTION
@@ -493,7 +494,7 @@ Now there are xUnit frameworks for every language from Ada to XSLT. You can find
 
 While xUnit frameworks are traditionally associated with unit testing they are also useful in the creation of functional/acceptance tests.
 
-Test::Class is (yet another) implementation of xUnit style testing in perl. 
+Test::Class is (yet another) implementation of xUnit style testing in Perl. 
 
 
 =head2 Why you should use Test::Class
@@ -605,7 +606,7 @@ If you don't know the number of tests at compile time you can use C<no_plan> lik
       my $objects = shift->{objects};
       isa_ok($_, "Object") foreach @$objects;
   };
-  
+
 or use the :Tests attribute, which acts just like C<:Test> but defaults to C<no_plan> if no number is given:
 
   sub check_class : Tests {
@@ -657,7 +658,7 @@ You can use these to create and destroy expensive objects that you don't want to
   sub db_connect : Test(startup) {
       shift->{dbi} = DBI->connect;
   };
-  
+
   sub db_disconnect : Test(shutdown) {
       shift->{dbi}->disconnect;
   };
@@ -667,7 +668,7 @@ Just like setup and teardown methods you can pass an optional number of tests to
   sub example : Test(startup => 1) {
       ok(1, 'a startup method with one test');
   };
-  
+
 If a startup method has a failing test or throws an exception then all other tests for the current test object are ignored. 
 
 =head1 RUNNING TESTS
@@ -1678,6 +1679,6 @@ A very simple unit testing framework.
 
 =head1 LICENCE
 
-Copyright 2002-2009 Adrian Howard, All Rights Reserved.
+Copyright 2002-2010 Adrian Howard, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
